# Package

## How to download and install pydagroas


To download the package from pypi and install into site-apckages use

    pip install pydagoras

To download and install a particular version eg 0.0.13 from github use

    pip install git+https://github.com/MarkHallett/pydagoras@v0.0.13


!!! warning
    It is good practice to install into a virtual env

The `pygraphviz` dependency will also be installed. This package is used to create the DAG images.

Also included in the package source (aviailable from github) are two files in the test folder, which are a file containing unit tests, and a script that shows basic use of the package.
